@@ -8,8 +8,8 @@ use tide::Request;
 use http_types::headers::HeaderValue;
 use tide::security::{CorsMiddleware, Origin};
 use tide_acme::{AcmeConfig, TideRustlsExt};
-use s3::{Bucket, BucketConfiguration};
-use s3::creds::Credentials;
+use s3compat::{Bucket, BucketConfiguration};
+use s3compat::creds::Credentials;
 use async_std::io::Cursor;
 extern crate biscuit_auth as biscuit;
 use biscuit::{crypto::PublicKey, token::Biscuit};
@@ -68,6 +68,9 @@ lazy_static! {
             "wa-us-west-1".to_string(), 
             "wa-eu-central-1".to_string()
         ]);
+        col.insert("vultr".to_string(), vec![
+            "ewr1".to_string(),
+        ]);
         Arc::new(col)
     };
 }
@@ -328,6 +331,7 @@ async fn provider(mut req: Request<()>) -> tide::Result {
                     Ok(tide::Response::builder(200).header("content-type", "application/json").build())
                 } else {
                     let j = json!({"error": "provider is invalid"});
+                    println!("{}", j);
                     Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build())
                 }
             } else {
@@ -377,12 +381,14 @@ async fn get_object(mut req: Request<()>) -> tide::Result {
                             },
                             None => {
                                 let j = json!({"error": "region not valid for provider"});
+                                println!("{}", j);
                                 return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                             }
                         }
                     },
                     None => {
                         let j = json!({"error": "region not valid for provider"});
+                        println!("{}", j);
                         return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                     }
                 }
@@ -415,7 +421,7 @@ async fn put_object(mut req: Request<()>) -> tide::Result {
 
                 match provider_maybe_name {
                     Some(provider_name) => {
-                        let provider_value  = get_provider_by_name(provider_name, username)?;
+                        let provider_value = get_provider_by_name(provider_name, username)?;
 
                         match provider_value {
                             Some(provider) => {
@@ -436,12 +442,14 @@ async fn put_object(mut req: Request<()>) -> tide::Result {
                             },
                             None => {
                                 let j = json!({"error": "region not valid for provider"});
+                                println!("{}", j);
                                 return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                             }
                         }
                     },
                     None => {
                         let j = json!({"error": "region not valid for provider"});
+                        println!("{}", j);
                         return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                     }
                 }
@@ -493,12 +501,14 @@ async fn delete_object(mut req: Request<()>) -> tide::Result {
                             },
                             None => {
                                 let j = json!({"error": "region not valid for provider"});
+                                println!("{}", j);
                                 return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                             }
                         }
                     },
                     None => {
                         let j = json!({"error": "region not valid for provider"});
+                        println!("{}", j);
                         return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                     }
                 }
@@ -549,17 +559,20 @@ async fn create_bucket(mut req: Request<()>) -> tide::Result {
                                     return Ok(tide::Response::builder(200).header("content-type", "application/json").build());
                                 } else {
                                     let j = json!({"error": bucket_response.response_text}).to_string();
+                                    println!("{}", j);
                                     return Ok(tide::Response::builder(bucket_response.response_code).body(j).header("content-type", "application/json").build());
                                 }
                             },
                             None => {
                                 let j = json!({"error": "region not valid for provider"});
+                                println!("{}", j);
                                 return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                             }
                         }
                     },
                     None => {
                         let j = json!({"error": "region not valid for provider"});
+                        println!("{}", j);
                         return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                     }
                 }
@@ -611,12 +624,14 @@ async fn delete_bucket(mut req: Request<()>) -> tide::Result {
                             },
                             None => {
                                 let j = json!({"error": "region not valid for provider"});
+                                println!("{}", j);
                                 return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                             }
                         }
                     },
                     None => {
                         let j = json!({"error": "region not valid for provider"});
+                        println!("{}", j);
                         return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                     }
                 }
@@ -680,17 +695,19 @@ async fn list_bucket(mut req: Request<()>) -> tide::Result {
                                 }
 
                                 let j = json!({"objects": objects}).to_string();
-
+                                println!("{}", j);
                                 return Ok(tide::Response::builder(200).body(j).header("content-type", "application/json").build());
                             },
                             None => {
                                 let j = json!({"error": "region not valid for provider"});
+                                println!("{}", j);
                                 return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                             }
                         }
                     },
                     None => {
                         let j = json!({"error": "region not valid for provider"});
+                        println!("{}", j);
                         return Ok(tide::Response::builder(400).body(j).header("content-type", "application/json").build());
                     }
                 }
